pub enum AnyDecryptedOlmEvent {
RoomKey(DecryptedRoomKeyEvent),
ForwardedRoomKey(DecryptedForwardedRoomKeyEvent),
SecretSend(DecryptedSecretSendEvent),
Dummy(DecryptedDummyEvent),
Custom(Box<ToDeviceCustomEvent>),
}Expand description
An enum over the various events that were decrypted using the
m.olm.v1.curve25519-aes-sha2 algorithm.
Variants
RoomKey(DecryptedRoomKeyEvent)
The m.room_key decrypted to-device event.
ForwardedRoomKey(DecryptedForwardedRoomKeyEvent)
The m.forwarded_room_key decrypted to-device event.
SecretSend(DecryptedSecretSendEvent)
The m.secret.send decrypted to-device event.
Dummy(DecryptedDummyEvent)
The m.dummy decrypted to-device event.
Custom(Box<ToDeviceCustomEvent>)
A decrypted to-device event of an unknown or custom type.
Implementations
Sourceimpl AnyDecryptedOlmEvent
impl AnyDecryptedOlmEvent
Sourcepub fn recipient(&self) -> &UserId
pub fn recipient(&self) -> &UserId
The intended recipient of the event, as set by the sender of the event.
Sourcepub fn recipient_keys(&self) -> &OlmV1Keys
pub fn recipient_keys(&self) -> &OlmV1Keys
The recipient’s signing keys of the encrypted event.
Sourcepub fn event_type(&self) -> &str
pub fn event_type(&self) -> &str
The event type of the encrypted event.
Sourcepub fn sender_device_keys(&self) -> Option<&DeviceKeys>
pub fn sender_device_keys(&self) -> Option<&DeviceKeys>
The sender’s device keys, if supplied in the message as per MSC4147